@@ -38,7 +38,8 @@ func GoldenFileCommandTest(t *testing.T, testName string, args []string, options
 	}
 
 	// Fix the VCS repo URL so the golden files don't fail on forks
-	os.Setenv("INFRACOST_VCS_REPOSITORY_URL", "https://github.com/infracost/infracost.git")
+	os.Setenv("INFRACOST_VCS_REPOSITORY_URL", "https://github.com/infracost/infracost")
+	os.Setenv("INFRACOST_VCS_PULL_REQUEST_URL", "NOT_APPLICABLE")
 
 	runCtx, err := config.NewRunContextFromEnv(context.Background())
 	require.Nil(t, err)
