@@ -7,12 +7,16 @@ import (
 	"io"
 	"os"
 	"runtime"
+	"sort"
 	"strings"
+	"sync"
 	"time"
 
 	"github.com/Rhymond/go-money"
 	"golang.org/x/sync/errgroup"
 
+	"github.com/pkg/errors"
+
 	"github.com/infracost/infracost/internal/apiclient"
 	"github.com/infracost/infracost/internal/clierror"
 	"github.com/infracost/infracost/internal/config"
@@ -22,12 +26,23 @@ import (
 	"github.com/infracost/infracost/internal/schema"
 	"github.com/infracost/infracost/internal/ui"
 	"github.com/infracost/infracost/internal/usage"
-	"github.com/pkg/errors"
 
 	log "github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 )
 
+type projectJob = struct {
+	index      int
+	projectCfg *config.Project
+}
+
+type projectResult = struct {
+	index    int
+	projects []*schema.Project
+}
+
+var validRunFormats = []string{"json", "table", "html"}
+
 func addRunFlags(cmd *cobra.Command) {
 	cmd.Flags().StringP("path", "p", "", "Path to the Terraform directory or JSON/plan file")
 
@@ -49,6 +64,10 @@ func addRunFlags(cmd *cobra.Command) {
 }
 
 func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
+	if runCtx.Config.IsSelfHosted() && runCtx.Config.EnableDashboard {
+		ui.PrintWarning(cmd.ErrOrStderr(), "The dashboard is part of Infracost's hosted services. Contact hello@infracost.io for help.")
+	}
+
 	parallelism, err := getParallelism(cmd, runCtx)
 	if err != nil {
 		return err
@@ -56,9 +75,9 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	runCtx.SetContextValue("parallelism", parallelism)
 
 	numJobs := len(runCtx.Config.Projects)
-	jobs := make(chan *config.Project, numJobs)
+	jobs := make(chan projectJob, numJobs)
 
-	projectResultChan := make(chan []*schema.Project, numJobs)
+	projectResultChan := make(chan projectResult, numJobs)
 	projectContextChan := make(chan *config.ProjectContext, numJobs)
 	errGroup, _ := errgroup.WithContext(context.Background())
 
@@ -74,27 +93,40 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 		}
 	}
 
+	// Create a mutex for each path, so we can synchronize the runs of any
+	// projects that have the same path. This is necessary because Terraform
+	// can't run multiple operations in parallel on the same path.
+	pathMuxs := map[string]*sync.Mutex{}
+	for _, projectCfg := range runCtx.Config.Projects {
+		pathMuxs[projectCfg.Path] = &sync.Mutex{}
+	}
+
 	for i := 0; i < parallelism; i++ {
 		errGroup.Go(func() error {
 
-			for projectCfg := range jobs {
-				ctx := config.NewProjectContext(runCtx, projectCfg)
+			for job := range jobs {
+				mux := pathMuxs[job.projectCfg.Path]
+
+				ctx := config.NewProjectContext(runCtx, job.projectCfg)
 				projectContextChan <- ctx
 
-				configProjects, err := runProjectConfig(cmd, runCtx, ctx, projectCfg)
+				configProjects, err := runProjectConfig(cmd, runCtx, ctx, job.projectCfg, mux)
 				if err != nil {
 					return err
 				}
 
-				projectResultChan <- configProjects
+				projectResultChan <- projectResult{
+					index:    job.index,
+					projects: configProjects,
+				}
 			}
 
 			return nil
 		})
 	}
 
-	for _, p := range runCtx.Config.Projects {
-		jobs <- p
+	for i, p := range runCtx.Config.Projects {
+		jobs <- projectJob{index: i, projectCfg: p}
 	}
 	close(jobs)
 
@@ -110,9 +142,17 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	}
 
 	close(projectResultChan)
+	projectResults := make([]projectResult, 0, len(runCtx.Config.Projects))
+	for result := range projectResultChan {
+		projectResults = append(projectResults, result)
+	}
+	sort.Slice(projectResults, func(i, j int) bool {
+		return projectResults[i].index < projectResults[j].index
+	})
+
 	projects := make([]*schema.Project, 0)
-	for projectResults := range projectResultChan {
-		projects = append(projects, projectResults...)
+	for _, projectResults := range projectResults {
+		projects = append(projects, projectResults.projects...)
 	}
 
 	r, err := output.ToOutputFormat(projects)
@@ -123,11 +163,13 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	r.Currency = runCtx.Config.Currency
 
 	dashboardClient := apiclient.NewDashboardAPIClient(runCtx)
-	r.RunID, err = dashboardClient.AddRun(runCtx, projectContexts, r)
+	result, err := dashboardClient.AddRun(runCtx, projectContexts, r)
 	if err != nil {
 		log.Errorf("Error reporting run: %s", err)
 	}
 
+	r.RunID, r.ShareURL = result.RunID, result.ShareURL
+
 	opts := output.Options{
 		DashboardEnabled: runCtx.Config.EnableDashboard,
 		ShowSkipped:      runCtx.Config.ShowSkipped,
@@ -158,7 +200,7 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	}
 
 	env := buildRunEnv(runCtx, projectContexts, r)
-	pricingClient := apiclient.NewPricingAPIClient(runCtx.Config)
+	pricingClient := apiclient.NewPricingAPIClient(runCtx)
 	err = pricingClient.AddEvent("infracost-run", env)
 	if err != nil {
 		log.Errorf("Error reporting event: %s", err)
@@ -181,7 +223,12 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	return nil
 }
 
-func runProjectConfig(cmd *cobra.Command, runCtx *config.RunContext, ctx *config.ProjectContext, projectCfg *config.Project) ([]*schema.Project, error) {
+func runProjectConfig(cmd *cobra.Command, runCtx *config.RunContext, ctx *config.ProjectContext, projectCfg *config.Project, mux *sync.Mutex) ([]*schema.Project, error) {
+	if mux != nil {
+		mux.Lock()
+		defer mux.Unlock()
+	}
+
 	for k, v := range projectCfg.Env {
 		os.Setenv(k, v)
 	}
@@ -284,11 +331,13 @@ func runProjectConfig(cmd *cobra.Command, runCtx *config.RunContext, ctx *config
 	spinnerOpts := ui.SpinnerOptions{
 		EnableLogging: runCtx.Config.IsLogging(),
 		NoColor:       runCtx.Config.NoColor,
+		Indent:        "  ",
 	}
-	spinner = ui.NewSpinner("Calculating monthly cost estimate", spinnerOpts)
+	spinner := ui.NewSpinner("Calculating monthly cost estimate", spinnerOpts)
+	defer spinner.Fail()
 
 	for _, project := range projects {
-		if err := prices.PopulatePrices(runCtx.Config, project); err != nil {
+		if err := prices.PopulatePrices(runCtx, project); err != nil {
 			spinner.Fail()
 			fmt.Fprintln(os.Stderr, "")
 
@@ -355,8 +404,11 @@ func generateUsageFile(cmd *cobra.Command, runCtx *config.RunContext, projectCtx
 		Indent:        "  ",
 	}
 
-	spinner = ui.NewSpinner("Syncing usage data from cloud", spinnerOpts)
+	spinner := ui.NewSpinner("Syncing usage data from cloud", spinnerOpts)
+	defer spinner.Fail()
+
 	syncResult, err := usage.SyncUsageData(usageFile, providerProjects)
+
 	if err != nil {
 		spinner.Fail()
 		return errors.Wrap(err, "Error synchronizing usage data")
@@ -475,6 +527,12 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 	cfg.NoCache, _ = cmd.Flags().GetBool("no-cache")
 
 	cfg.Format, _ = cmd.Flags().GetString("format")
+
+	if cfg.Format != "" && !contains(validRunFormats, cfg.Format) {
+		ui.PrintUsage(cmd)
+		return fmt.Errorf("--format only supports %s", strings.Join(validRunFormats, ", "))
+	}
+
 	cfg.ShowSkipped, _ = cmd.Flags().GetBool("show-skipped")
 	cfg.SyncUsageFile, _ = cmd.Flags().GetBool("sync-usage-file")
 
