@@ -15,7 +15,7 @@ import (
 // Project defines a specific terraform project config. This can be used
 // specify per folder/project configurations so that users don't have
 // to provide flags every run. Fields are documented below. More info
-// is outlined here: https://www.infracost.io/docs/multi_project/config_file/
+// is outlined here: https://www.infracost.io/config-file
 type Project struct {
 	// Path to the Terraform directory or JSON/plan file.
 	// A path can be repeated with different parameters, e.g. for multiple workspaces.
@@ -57,7 +57,7 @@ type Config struct {
 	DashboardAPIEndpoint      string `yaml:"dashboard_api_endpoint,omitempty" envconfig:"INFRACOST_DASHBOARD_API_ENDPOINT"`
 	EnableDashboard           bool   `yaml:"enable_dashboard,omitempty" envconfig:"INFRACOST_ENABLE_DASHBOARD"`
 
-	TLSInsecureSkipVerify bool   `envconfig:"INFRACOST_TLS_INSECURE_SKIP_VERIFY"`
+	TLSInsecureSkipVerify *bool  `envconfig:"INFRACOST_TLS_INSECURE_SKIP_VERIFY"`
 	TLSCACertFile         string `envconfig:"INFRACOST_TLS_CA_CERT_FILE"`
 
 	Currency string `envconfig:"INFRACOST_CURRENCY"`
@@ -91,6 +91,7 @@ func DefaultConfig() *Config {
 		DefaultPricingAPIEndpoint: "https://pricing.api.infracost.io",
 		PricingAPIEndpoint:        "",
 		DashboardAPIEndpoint:      "https://dashboard.api.infracost.io",
+		EnableDashboard:           false,
 
 		Projects: []*Project{{}},
 
@@ -199,6 +200,10 @@ func (c *Config) IsLogging() bool {
 	return c.LogLevel != ""
 }
 
+func (c *Config) IsSelfHosted() bool {
+	return c.PricingAPIEndpoint != "" && c.PricingAPIEndpoint != c.DefaultPricingAPIEndpoint
+}
+
 func IsTest() bool {
 	return os.Getenv("INFRACOST_ENV") == "test" || strings.HasSuffix(os.Args[0], ".test")
 }
