@@ -2,6 +2,7 @@ package output
 
 import (
 	"fmt"
+	"strings"
 
 	"github.com/dustin/go-humanize"
 	"github.com/fatih/color"
@@ -18,16 +19,21 @@ const (
 func ToDiff(out Root, opts Options) ([]byte, error) {
 	s := ""
 
-	hasNilCosts := false
-	hasEmptyDiff := true
+	noDiffProjects := make([]string, 0)
 
 	for i, project := range out.Projects {
 		if project.Diff == nil {
 			continue
 		}
 
+		// Check whether there is any diff or not
+		if len(project.Diff.Resources) == 0 {
+			noDiffProjects = append(noDiffProjects, project.Label(opts.DashboardEnabled))
+			continue
+		}
+
 		if i != 0 {
-			s += "----------------------------------\n"
+			s += "──────────────────────────────────\n"
 		}
 
 		s += fmt.Sprintf("%s %s\n\n",
@@ -36,16 +42,9 @@ func ToDiff(out Root, opts Options) ([]byte, error) {
 		)
 
 		for _, diffResource := range project.Diff.Resources {
-			hasEmptyDiff = false
-
 			oldResource := findResourceByName(project.PastBreakdown.Resources, diffResource.Name)
 			newResource := findResourceByName(project.Breakdown.Resources, diffResource.Name)
 
-			if (newResource == nil || resourceHasNilCosts(*newResource)) &&
-				(oldResource == nil || resourceHasNilCosts(*oldResource)) {
-				hasNilCosts = true
-			}
-
 			s += resourceToDiff(out.Currency, diffResource, oldResource, newResource, true)
 			s += "\n"
 		}
@@ -64,7 +63,7 @@ func ToDiff(out Root, opts Options) ([]byte, error) {
 			ui.BoldString("Monthly cost change for"),
 			ui.BoldString(project.Label(opts.DashboardEnabled)),
 			formatTitleWithCurrency(formatCostChange(out.Currency, project.Diff.TotalMonthlyCost), out.Currency),
-			ui.FaintStringf("(%s -> %s)", formatCost(out.Currency, oldCost), formatCost(out.Currency, newCost)),
+			ui.FaintStringf("(%s → %s)", formatCost(out.Currency, oldCost), formatCost(out.Currency, newCost)),
 		)
 
 		percent := formatPercentChange(oldCost, newCost)
@@ -74,32 +73,31 @@ func ToDiff(out Root, opts Options) ([]byte, error) {
 			)
 		}
 
-		if i != len(out.Projects)-1 {
-			s += "\n\n"
-		}
+		s += "\n\n"
 	}
 
-	s += "\n\n----------------------------------\n"
-	s += fmt.Sprintf("Key: %s changed, %s added, %s removed",
-		opChar(UPDATED),
-		opChar(ADDED),
-		opChar(REMOVED),
-	)
+	if len(noDiffProjects) > 0 {
+		s += "──────────────────────────────────\n"
+		s += fmt.Sprintf("\nThe following projects have no cost estimate changes: %s", strings.Join(noDiffProjects, ", "))
+		s += fmt.Sprintf("\nRun %s to see their full breakdown.", ui.PrimaryString("infracost breakdown"))
+		s += "\n\n"
+	}
 
-	if hasNilCosts {
-		s += fmt.Sprintf("\n\nTo estimate usage-based resources use --usage-file, see %s",
-			ui.LinkString("https://infracost.io/usage-file"),
+	s += "──────────────────────────────────\n"
+	if len(noDiffProjects) != len(out.Projects) {
+		s += fmt.Sprintf("Key: %s changed, %s added, %s removed\n",
+			opChar(UPDATED),
+			opChar(ADDED),
+			opChar(REMOVED),
 		)
 	}
 
-	if hasEmptyDiff {
-		s += fmt.Sprintf("\n\nNo changes detected. Run %s to see the full breakdown.",
-			ui.PrimaryString("infracost breakdown"))
-	}
-
-	unsupportedMsg := out.unsupportedResourcesMessage(opts.ShowSkipped)
+	unsupportedMsg := out.summaryMessage(opts.ShowSkipped)
 	if unsupportedMsg != "" {
-		s += "\n\n" + unsupportedMsg
+		if len(noDiffProjects) != len(out.Projects) {
+			s += "\n"
+		}
+		s += unsupportedMsg
 	}
 
 	return []byte(s), nil
@@ -147,11 +145,11 @@ func resourceToDiff(currency string, diffResource Resource, oldResource *Resourc
 		var oldComponent, newComponent *CostComponent
 
 		if oldResource != nil {
-			oldComponent = findCostComponentByName(oldResource.CostComponents, diffComponent.Name)
+			oldComponent = findMatchingCostComponent(oldResource.CostComponents, diffComponent.Name)
 		}
 
 		if newResource != nil {
-			newComponent = findCostComponentByName(newResource.CostComponents, diffComponent.Name)
+			newComponent = findMatchingCostComponent(newResource.CostComponents, diffComponent.Name)
 		}
 
 		s += "\n"
@@ -198,7 +196,7 @@ func costComponentToDiff(currency string, diffComponent CostComponent, oldCompon
 		newPrice = &newComponent.Price
 	}
 
-	s += fmt.Sprintf("%s %s\n", opChar(op), diffComponent.Name)
+	s += fmt.Sprintf("%s %s\n", opChar(op), colorizeDiffName(diffComponent.Name))
 
 	if oldCost == nil && newCost == nil {
 		s += "  Monthly cost depends on usage\n"
@@ -217,6 +215,11 @@ func costComponentToDiff(currency string, diffComponent CostComponent, oldCompon
 	return s
 }
 
+// colorizeDiffName colorizes any arrows in the name
+func colorizeDiffName(name string) string {
+	return strings.ReplaceAll(name, " → ", fmt.Sprintf(" %s ", color.YellowString("→")))
+}
+
 func opChar(op int) string {
 	switch op {
 	case ADDED:
@@ -238,10 +241,20 @@ func findResourceByName(resources []Resource, name string) *Resource {
 	return nil
 }
 
-func findCostComponentByName(costComponents []CostComponent, name string) *CostComponent {
-	for _, c := range costComponents {
-		if c.Name == name {
-			return &c
+// findMatchingCostComponent finds a matching cost component by first looking for an exact match by name
+// and if that's not found, looking for a match of everything before any brackets.
+func findMatchingCostComponent(costComponents []CostComponent, name string) *CostComponent {
+	for _, costComponent := range costComponents {
+		if costComponent.Name == name {
+			return &costComponent
+		}
+	}
+
+	for _, costComponent := range costComponents {
+		splitKey := strings.Split(name, " (")
+		splitName := strings.Split(costComponent.Name, " (")
+		if len(splitKey) > 1 && len(splitName) > 1 && splitName[0] == splitKey[0] {
+			return &costComponent
 		}
 	}
 
@@ -262,7 +275,7 @@ func formatCostChangeDetails(currency string, oldCost *decimal.Decimal, newCost
 		return ""
 	}
 
-	return fmt.Sprintf(" (%s -> %s)", formatCost(currency, oldCost), formatCost(currency, newCost))
+	return fmt.Sprintf(" (%s → %s)", formatCost(currency, oldCost), formatCost(currency, newCost))
 }
 
 func formatPriceChange(currency string, d decimal.Decimal) string {
@@ -275,7 +288,7 @@ func formatPriceChangeDetails(currency string, oldPrice *decimal.Decimal, newPri
 		return ""
 	}
 
-	return fmt.Sprintf(" (%s -> %s)", formatPrice(currency, *oldPrice), formatPrice(currency, *newPrice))
+	return fmt.Sprintf(" (%s → %s)", formatPrice(currency, *oldPrice), formatPrice(currency, *newPrice))
 }
 
 func formatPercentChange(oldCost *decimal.Decimal, newCost *decimal.Decimal) string {
