@@ -17,6 +17,7 @@ var outputVersion = "0.2"
 type Root struct {
 	Version              string           `json:"version"`
 	RunID                string           `json:"runId,omitempty"`
+	ShareURL             string           `json:"shareUrl,omitempty"`
 	Currency             string           `json:"currency"`
 	Projects             []Project        `json:"projects"`
 	TotalHourlyCost      *decimal.Decimal `json:"totalHourlyCost"`
@@ -340,6 +341,10 @@ func (r *Root) summaryMessage(showSkipped bool) string {
 		}
 	}
 
+	if r.ShareURL != "" {
+		msg += fmt.Sprintf("\n\nShare the results: %s", ui.LinkString(r.ShareURL))
+	}
+
 	return msg
 }
 
