@@ -20,7 +20,7 @@ func NewAzureRMKeyVaultManagedHSM(d *schema.ResourceData, u *schema.UsageData) *
 	costComponents = append(costComponents, &schema.CostComponent{
 		Name:           "HSM pools",
 		Unit:           "hours",
-		UnitMultiplier: 1,
+		UnitMultiplier: decimal.NewFromInt(1),
 		HourlyQuantity: decimalPtr(decimal.NewFromInt(1)),
 		ProductFilter: &schema.ProductFilter{
 			VendorName:    strPtr("azure"),
